import pandas as pd


def getRandomMaleName(numberNames=1, fullName=False, files=None):

    name = pd.read_csv(files[0])
    if numberNames >= 2:
        result_array = []
        surname = pd.read_csv(files[1])
        for i in range(numberNames):
            temporal_return = name.sample()["nombre"].to_string(
                index=False).strip()
            if fullName:
                temporal_return += " "
                temporal_return += surname.sample(
                )["apellido"].to_string(index=False)
                temporal_return += " "
                temporal_return += surname.sample(
                )["apellido"].to_string(index=False)
            result_array.append(temporal_return)
        return result_array
    else:
        result_string = name.sample()["nombre"].to_string(index=False).strip()
        return result_string


def getRandomFemaleName(numberNames=1, fullName=False, files=None):

    name = pd.read_csv(files[0])
    if numberNames >= 2:
        result_array = []
        surname = pd.read_csv(files[1])
        for i in range(numberNames):
            temporal_return = name.sample()["nombre"].to_string(
                index=False).strip()
            if fullName:
                temporal_return += " "
                temporal_return += surname.sample(
                )["apellido"].to_string(index=False)
                temporal_return += " "
                temporal_return += surname.sample(
                )["apellido"].to_string(index=False)
            result_array.append(temporal_return)
        return result_array
    else:
        result_string = name.sample()["nombre"].to_string(index=False).strip()
        return result_string


def getRandomSurname(numberSurnames=1, pairs=False, files=None):

    surname = pd.read_csv(files[0])
    if numberSurnames >= 2:
        result_array = []
        tmp = ""
        for i in range(numberSurnames):
            if pairs:
                tmp = surname.sample()["apellido"].to_string(index=False)
            result_array.append(
                surname.sample()["apellido"].to_string(index=False) + " " + tmp)
        return result_array
    else:
        tmp = ""
        if pairs:
            tmp = surname.sample()["apellido"].to_string(index=False)
        return f"{surname.sample()['apellido'].to_string(index=False) + ' ' + tmp}"



import pathlib
from setuptools import find_packages, setup

HERE = pathlib.Path(__file__).parent

VERSION = '1.5'
PACKAGE_NAME = 'lap_random_spanish'  # Debe coincidir con el nombre de la carpeta
AUTHOR = '@lap.com'  # Modificar con vuestros datos
AUTHOR_EMAIL = 'lapfreelance56@gmail.com'  # Modificar con vuestros datos
# Modificar con vuestros datos
URL = 'https://github.com/LuisAlbertoPerezDeLaCruz/lap_random_spanish.git'

LICENSE = 'GNU GPL'  # Tipo de licencia
DESCRIPTION = 'Library to obtain names of Spanish men and women as well as surnames'
LONG_DESCRIPTION = (HERE / "README.md").read_text(encoding='utf-8')
LONG_DESC_TYPE = "text/markdown"


# Paquetes necesarios para que funcione la libreía. Se instalarán a la vez si no lo tuvieras ya instalado
INSTALL_REQUIRES = [
    'pandas'
]

setup(
    name=PACKAGE_NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type=LONG_DESC_TYPE,
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    url=URL,
    install_requires=INSTALL_REQUIRES,
    license=LICENSE,
    packages=find_packages(),
    include_package_data=True
)
